RapidPro Dash Library
=====================

[![Build Status](https://github.com/rapidpro/dash/workflows/CI/badge.svg)](https://github.com/rapidpro/dash/actions?query=workflow%3ACI) 
[![codecov](https://codecov.io/gh/rapidpro/dash/branch/main/graph/badge.svg)](https://codecov.io/gh/rapidpro/dash)
[![PyPI Release](https://img.shields.io/pypi/v/rapidpro-dash.svg)](https://pypi.python.org/pypi/rapidpro-dash/)

Support library for building dashboards applications for [RapidPro](https://github.com/rapidpro/rapidpro).

* Provides an organization app to support multi-tenant sites
* Reusable user management views
* Supports Python 3 only
* Supports Django 1.11 and 2.0
